==> facebook-nodejs-business-sdk-4.0.8.tgz: package/docs/PAGE_FEED_WITH_PHOTO_CREATE.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const Page = bizSdk.Page;
const Photo = bizSdk.Photo;
const PagePost = bizSdk.PagePost;
const AbstractObject = bizSdk.AbstractObject;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let page_access_token = 'EAARZAZA73LzF0BAHrXWeZCZC97m9uWcDbydlhuI7B8jpzL5fFg5ytac07oAUZBrA7RkKaQ249VTKEmBZAfqDwSW4iEbduKvUelxvyAwZA3muCrCW5i5KUYBOahFjICJnYOZC9y0Yl56ZCfFN2r17sYu7BnB8mu68ZC0GWDErL2fMSekG0cCZCFvryz3u4yFfzZCkHHYUEoGAxZAq1ZAwZDZD';
let page_id = '190446001681363';
const api = bizSdk.FacebookAdsApi.init(
  access_token
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [business_api]
//  _DOC open [PAGE_FEED_WITH_PHOTO_CREATE]
bizSdk.FacebookAdsApi.init(page_access_token);
fields = [
];
params = {
  'url' : 'https://www.facebook.com/images/fb_icon_325x325.png',
  'published' : 'false',
};
let photo_to_be_post = await (new Page(page_id)).createPhoto(
  fields,
  params
);
let photo_to_be_post_id = photo_to_be_post.id;
fields = [
  'object_id',
];
params = {
  'message' : 'I have something good for you!',
  'attached_media' : [{'media_fbid': photo_to_be_post_id}],
};
let feed_post_with_image = await (new Page(page_id)).createFeed(
  fields,
  params
);
let feed_post_with_image_id = feed_post_with_image.id;
fields = [
];
params = {
};
await (new PagePost(feed_post_with_image_id)).delete(
  params
);

//  _DOC close [PAGE_FEED_WITH_PHOTO_CREATE]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();

==> facebook-nodejs-business-sdk-6.0.0.tgz: package/docs/PAGE_FEED_WITH_PHOTO_CREATE.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const Page = bizSdk.Page;
const Photo = bizSdk.Photo;
const PagePost = bizSdk.PagePost;
const AbstractObject = bizSdk.AbstractObject;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let page_access_token = 'EAARZAZA73LzF0BAHrXWeZCZC97m9uWcDbydlhuI7B8jpzL5fFg5ytac07oAUZBrA7RkKaQ249VTKEmBZAfqDwSW4iEbduKvUelxvyAwZA3muCrCW5i5KUYBOahFjICJnYOZC9y0Yl56ZCfFN2r17sYu7BnB8mu68ZC0GWDErL2fMSekG0cCZCFvryz3u4yFfzZCkHHYUEoGAxZAq1ZAwZDZD';
let page_id = '190446001681363';
const api = bizSdk.FacebookAdsApi.init(
  access_token,
  crash_log=false
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [business_api]
//  _DOC open [PAGE_FEED_WITH_PHOTO_CREATE]
bizSdk.FacebookAdsApi.init(page_access_token, crash_log=false);
fields = [
];
params = {
  'url' : 'https://www.facebook.com/images/fb_icon_325x325.png',
  'published' : 'false',
};
let photo_to_be_post = await (new Page(page_id)).createPhoto(
  fields,
  params
);
let photo_to_be_post_id = photo_to_be_post.id;
fields = [
  'object_id',
];
params = {
  'message' : 'I have something good for you!',
  'attached_media' : [{'media_fbid': photo_to_be_post_id}],
};
let feed_post_with_image = await (new Page(page_id)).createFeed(
  fields,
  params
);
let feed_post_with_image_id = feed_post_with_image.id;
fields = [
];
params = {
};
await (new PagePost(feed_post_with_image_id)).delete(
  params
);

//  _DOC close [PAGE_FEED_WITH_PHOTO_CREATE]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();
